# YumeValidator CLI

> CLI Tool to execute UI Validation AI Agent and display the report after the process has been completed

## Available Commands

### Install
```
pip3 install --editable .
```

### Check Version
```
yumevalidator version
```

### Initialize CLI for a project
```
yumevalidator init
```

### Display previous report
```
yumevalidator report
```

### Start running tests
```
yumevalidator test

```